==> cocoindex-0.1.64.tar.gz: cocoindex-0.1.64/docs/docs/about/community.md <==
---
title: Community
description: Join the CocoIndex community
---

# Community

Welcome with a huge coconut hug 🥥⋆｡˚🤗.

We are super excited for community contributions of all kinds - whether it's code improvements, documentation updates, issue reports, feature requests on [GitHub](https://github.com/cocoindex-io/cocoindex), and discussions in our [Discord](https://discord.com/invite/zpA9S2DR7s).

We would love to fostering an inclusive, welcoming, and supportive environment. Contributing to CocoIndex should feel collaborative, friendly and enjoyable for everyone. Together, we can build better AI applications through robust data infrastructure.

:::tip Start hacking CocoIndex
Check out our [Contributing guide](./contributing) to get started!
:::


## Connect With Us

Join our community channels to get help, share ideas, and connect with other developers:

- [Discord Community](https://discord.com/invite/zpA9S2DR7s) - Chat with the community and get real-time support
- [Twitter](https://x.com/cocoindex_io) - Follow us for updates and announcements
- [LinkedIn](https://www.linkedin.com/company/cocoindex/about/) - Connect professionally
- [YouTube](https://www.youtube.com/@cocoindex-io) - Watch tutorials and demos

## Get Support

Need help? Here are the best ways to get support:

- Email us at [hi@cocoindex.io](mailto:hi@cocoindex.io)
- Check our [documentation](https://cocoindex.io/docs)
- Read our [blog posts](https://cocoindex.io/blogs)
- Ask questions in our [Discord Server](https://discord.com/invite/zpA9S2DR7s)

==> cocoindex-0.1.75.tar.gz: cocoindex-0.1.75/docs/docs/about/community.md <==
---
title: Community
description: Join the CocoIndex community
---

# Community

Welcome with a huge coconut hug 🥥⋆｡˚🤗.

We are super excited for community contributions of all kinds - whether it's code improvements, documentation updates, issue reports, feature requests on [GitHub](https://github.com/cocoindex-io/cocoindex), and discussions in our [Discord](https://discord.com/invite/zpA9S2DR7s).

We would love to foster an inclusive, welcoming, and supportive environment. Contributing to CocoIndex should feel collaborative, friendly and enjoyable for everyone. Together, we can build better AI applications through robust data infrastructure.

:::tip Start hacking CocoIndex
Check out our [Contributing guide](./contributing) to get started!
:::


## Connect With Us

Join our community channels to get help, share ideas, and connect with other developers:

- [Discord Community](https://discord.com/invite/zpA9S2DR7s) - Chat with the community and get real-time support
- [Twitter](https://x.com/cocoindex_io) - Follow us for updates and announcements
- [LinkedIn](https://www.linkedin.com/company/cocoindex/about/) - Connect professionally
- [YouTube](https://www.youtube.com/@cocoindex-io) - Watch tutorials and demos

## Get Support

Need help? Here are the best ways to get support:

- Email us at [hi@cocoindex.io](mailto:hi@cocoindex.io)
- Check our [documentation](https://cocoindex.io/docs)
- Read our [blog posts](https://cocoindex.io/blogs)
- Ask questions in our [Discord Server](https://discord.com/invite/zpA9S2DR7s)
